@@ -49,15 +49,30 @@ class KnowledgeBase:
             documents[document['id']] = kb_document
         return documents
 
+    def query(self, query: str, top_k: int = 10):
+        url = BASE_URL + f'knowledge_bases/{self.kb_id}/query'
+        payload = {
+            'query': query,
+            'top_k': top_k,
+        }
+        resp = _format_http_response(requests.post(url, headers=get_headers(), json=payload))
+        return resp["body"]
+
+    def delete(self):
+        url = BASE_URL + f'knowledge_bases/{self.kb_id}'
+        resp = _format_http_response(requests.delete(url, headers=get_headers()))
+        return resp
+
 
 class KnowledgeBaseDocument:
-    def __init__(self, kb_id: str, content: str, title: str = None, link_to_source: str = None, supp_id: str = None, description: str = None):
+    def __init__(self, kb_id: str, content: str, title: str = None, link_to_source: str = None, supp_id: str = None, description: str = None, doc_id: str = None):
         self.kb_id = kb_id
         self.content = content # content is a string
         self.title = title
         self.link_to_source = link_to_source
         self.supp_id = supp_id
         self.description = description
+        self.doc_id = doc_id
 
     def create(self):
         url = BASE_URL + f'knowledge_bases/{self.kb_id}/documents'
@@ -75,6 +90,11 @@ class KnowledgeBaseDocument:
         resp = _format_http_response(requests.post(url, headers=get_headers(), json=payload))
         return resp['body']
 
+    def delete(self):
+        url = BASE_URL + f'knowledge_bases/{self.kb_id}/documents/{self.doc_id}'
+        resp = _format_http_response(requests.delete(url, headers=get_headers()))
+        return resp
+
 
 def get_knowledge_bases():
     knowledge_bases = {}
@@ -107,7 +127,8 @@ def get_knowledge_base(title: str):
         if kb.title not in kb_from_title:
             kb_from_title[kb.title] = kb
         else:
-            raise Exception('Duplicate knowledge base title: ' + kb.title)
+            print ('WARNING: Duplicate knowledge base title: ' + kb.title)
+            #raise Exception('Duplicate knowledge base title: ' + kb.title)
     
     # if the title we're looking for is in the map, return the KnowledgeBase object
     if title in kb_from_title:
